@@ -99,24 +99,22 @@ class FacebookLikableModel(models.Model):
         Retrieve and save all likes of post
         '''
         response = graph('%s/likes' % self.graph_id, limit=limit, offset=offset)
-        if not response:
-            return
+        if response:
+            if delete_all:
+                self.like_users.clear()
 
-        if delete_all:
-            self.like_users.clear()
+            response_count = len(response.data)
+            for resource in response.data:
+                user = get_or_create_from_small_resource(resource)
+                self.like_users.add(user)
+                log.debug('like users count - %s' % self.like_users.count())
+            log.debug('response objects count - %s, limit - %s, offset - %s' % (response_count, limit, offset))
 
-        response_count = len(response.data)
-        for resource in response.data:
-            user = get_or_create_from_small_resource(resource)
-            self.like_users.add(user)
-            log.debug('like users count - %s' % self.like_users.count())
-        log.debug('response objects count - %s, limit - %s, offset - %s' % (response_count, limit, offset))
-
-        if response_count != 0:
-            return self.fetch_likes(limit=limit, offset=offset+response_count, delete_all=False)
-        else:
-            self.likes_count = self.like_users.count()
-            self.save()
+            if response_count != 0:
+                return self.fetch_likes(limit=limit, offset=offset+response_count, delete_all=False)
+            else:
+                self.likes_count = self.like_users.count()
+                self.save()
 
         return self.like_users.all()
 
@@ -124,7 +122,6 @@ class Post(FacebookGraphIDModel, FacebookLikableModel):
     class Meta:
         verbose_name = 'Facebook post'
         verbose_name_plural = 'Facebook posts'
-        ordering = ['-created_time']
 
     like_users = models.ManyToManyField(User, related_name='like_posts')
 
@@ -220,17 +217,16 @@ class Post(FacebookGraphIDModel, FacebookLikableModel):
         '''
         Retrieve and save all comments of post
         '''
-        response = graph('%s/comments' % self.graph_id, limit=limit, offset=offset)
-        if not response:
-            return
-
-        log.debug('response objects count - %s, limit - %s, offset - %s' % (len(response.data), limit, offset))
-
         instances = Comment.objects.none()
-        for resource in response.data:
-            instance = Comment.remote.get_or_create_from_resource(resource, {'post_id': self.id})
-            log.debug('comments count - %s' % Comment.objects.count())
-            instances |= Comment.objects.filter(pk=instance.pk)
+
+        response = graph('%s/comments' % self.graph_id, limit=limit, offset=offset)
+        if response:
+            log.debug('response objects count - %s, limit - %s, offset - %s' % (len(response.data), limit, offset))
+
+            for resource in response.data:
+                instance = Comment.remote.get_or_create_from_resource(resource, {'post_id': self.id})
+                log.debug('comments count - %s' % Comment.objects.count())
+                instances |= Comment.objects.filter(pk=instance.pk)
 
         return instances
 
@@ -263,7 +259,6 @@ class PostOwner(models.Model):
     '''
     class Meta:
         unique_together = ('post','owner_content_type','owner_id')
-        ordering = ('post',)
 
     post = models.ForeignKey(Post, related_name='owners')
 
@@ -291,7 +286,6 @@ class Comment(FacebookGraphIDModel, FacebookLikableModel):
     class Meta:
         verbose_name = 'Facebook comment'
         verbose_name_plural = 'Facebook comments'
-        ordering = ['-created_time']
 
     like_users = models.ManyToManyField(User, related_name='like_comments')
 
